#include <string.h>
#include "UART1.h"
#include "GLIB.h"                            

             
#define STX 0x02
#define ETX 0x03       

//==================================================================
//                     LCD  ɱ
//==================================================================

//--------------------- Glib_InitLCD Function ----------------------
//  : 0x02 0x1A 0x10 0x03
void Glib_InitLCD(void)
{
    RsOut1(STX);
    RsOut1(0x1A);
    RsOut1(0x10);
    RsOut1(ETX);
}

//-------------------- Glib_SetBaudRate Function --------------------
//  : 0x02 0x1A 0x11 br 0x03
// 1200bps -> 0,  2400bps -> 1,  4800bps -> 2, 9600bps ->3
// 19200bps -> 4(Default), 38400bps -> 5, 57600bps -> 6, 115200bps -> 7
void Glib_SetBaudRate(unsigned char br)
{
    RsOut1(STX);
    RsOut1(0x1A);
    RsOut1(0x11);
    RsOut1(br);    
    RsOut1(ETX);    
}                                         

//--------------------- Glib_TspOnOff Function ----------------------
//  : 0x02 0x1A 0x12 flag 0x03
// flag: 0xA0->ON,  0x0A->OFF(Default)
void Glib_TspOnOff(unsigned char flag)
{
    RsOut1(STX);
    RsOut1(0x1A);
    RsOut1(0x12);
    RsOut1(flag);    
    RsOut1(ETX);   
}
 
//-------------------- Glib_SetTspMode Function ---------------------
//  : 0x02 0x1A 0x13 flag 0x03
// flag: 0xA0->Up/Down Event(Default),  0x0A->Down Event only
void Glib_SetTspMode(unsigned char flag)
{
    RsOut1(STX);
    RsOut1(0x1A);
    RsOut1(0x13);
    RsOut1(flag);    
    RsOut1(ETX);   
}

//------------------- Glib_LcdBackLight Function --------------------
//  : 0x02 0x1A 0x14 flag 0x03
// flag: 0xA0->On,  0x0A->Off(default)
void Glib_LcdBackLight(unsigned char flag)
{
    RsOut1(STX);
    RsOut1(0x1A);
    RsOut1(0x14);
    RsOut1(flag);    
    RsOut1(ETX);   
}

//---------------- Glib_SetFullDisplayMode Function -----------------
//  : 0x02 0x1A 0x15 flag 0x03
// flag: 0xA0->use PCI function(default),  0x0A->don't use PCI function
void Glib_SetFullDisplayMode(unsigned char flag)
{
    RsOut1(STX);
    RsOut1(0x15);
    RsOut1(0x14);
    RsOut1(flag);    
    RsOut1(ETX);   
}

         
//==================================================================
//                      ׷  ɱ
//==================================================================                                                                     

//------------------ Glib_SetHangulFont Function -------------------
//  : 0x02 0x1B 0x10 hIndex 0x03
// hIndex: ѱ۸1->0(default), ѱ۸2->1, ѱ۰°->2
//         ѱ۱->3, ѱʱü->4          
void Glib_SetHangulFont(unsigned char hIndex)
{
    RsOut1(STX);
    RsOut1(0x1B);
    RsOut1(0x10);
    RsOut1(hIndex);    
    RsOut1(ETX);   
}
 
//------------------ Glib_SetEnglishFont Function -------------------
//  : 0x02 0x1B 0x11 eIndex 0x03
// hIndex: 1->0(default), 2->1, θ->2
//         ->3, ü->4          
void Glib_SetEnglishFont(unsigned char eIndex)
{
    RsOut1(STX);
    RsOut1(0x1B);
    RsOut1(0x11);
    RsOut1(eIndex);    
    RsOut1(ETX);   
}

 
//------------------ Glib_SetFontColor Function -------------------
//  : 0x02 0x1B 0x12 ForeColor BackColor 0x03
// ForeColor, Backcolor -> R G B   1Ʈ  3Ʈ 
// Default -> ForeColor:Black, BackColor=White
void Glib_SetFontColor(unsigned long fColor, unsigned long bColor)
{
    RsOut1(STX);
    RsOut1(0x1B);
    RsOut1(0x12);
    RsOut1((unsigned char)((fColor>>16)&0xFF));
    RsOut1((unsigned char)((fColor>>8)&0xFF));
    RsOut1((unsigned char)(fColor&0xFF)); 
    RsOut1((unsigned char)((bColor>>16)&0xFF));
    RsOut1((unsigned char)((bColor>>8)&0xFF));
    RsOut1((unsigned char)(bColor&0xFF)); 
    RsOut1(ETX);   
}

//------------------ Glib_SetLineColor Function -------------------
//  : 0x02 0x1B 0x13 LineColor 0x03
// LineColor -> R G B   1Ʈ  3Ʈ      
// Default -> Black
void Glib_SetLineColor(unsigned long lineColor)
{
    RsOut1(STX);
    RsOut1(0x1B);
    RsOut1(0x13);
    RsOut1((unsigned char)((lineColor>>16)&0xFF));
    RsOut1((unsigned char)((lineColor>>8)&0xFF));
    RsOut1((unsigned char)(lineColor&0xFF)); 
    RsOut1(ETX);   
} 

//------------------ Glib_SetLineWidth Function -------------------
//  : 0x02 0x1B 0x14 LineWidth 0x03
// LineWidth -> 1~7 (default=1)
void Glib_SetLineWidth(unsigned char lineWidth)
{
    RsOut1(STX);
    RsOut1(0x1B);
    RsOut1(0x14);
    RsOut1(lineWidth); 
    RsOut1(ETX);   
}   


//==================================================================
//                      Ʈ ɱ
//==================================================================                                                                     

//-------------------- Glib_SetLocate Function ---------------------
//  : 0x02 0x1C 0x10 Xposition Yposition 0x03 
// Xposition, Yposition -> X, Y ǥ Ʈ    
// Default -> (0, 0)
void Glib_SetLocate(unsigned int xx, unsigned int yy)
{
    RsOut1(STX);
    RsOut1(0x1C);
    RsOut1(0x10);
    RsOut1((unsigned char)((xx>>8)&0xFF));
    RsOut1((unsigned char)(xx&0xFF)); 
    RsOut1((unsigned char)((yy>>8)&0xFF));
    RsOut1((unsigned char)(yy&0xFF));     
    RsOut1(ETX);
}               

//-------------------- Glib_SetZoomRate Function ---------------------
//  : 0x02 0x1C 0x11 ZoomRate 0x03 
// ZoomRate -> 1(default) or 2
void Glib_SetZoomRate(unsigned char zoomRate)
{
    RsOut1(STX);
    RsOut1(0x1C);
    RsOut1(0x11);
    RsOut1(zoomRate);     
    RsOut1(ETX);
}                  

//-------------------- Glib_FontBackMode Function ---------------------
//  : 0x02 0x1C 0x12 flag 0x03 
// flag -> 0xA0(use background font color, default), 0x0A(don't use)
void Glib_FontBackMode(unsigned char flag)
{
    RsOut1(STX);
    RsOut1(0x1C);
    RsOut1(0x12);
    RsOut1(flag);     
    RsOut1(ETX);
}                  
 
//-------------------- Glib_CursorOnOff Function ---------------------
//  : 0x02 0x1C 0x13 flag 0x03 
// flag -> 0xA0(cursor on), 0x0A(cursor off, default)
void Glib_CursorOnOff(unsigned char flag)
{
    RsOut1(STX);
    RsOut1(0x1C);
    RsOut1(0x13);
    RsOut1(flag);     
    RsOut1(ETX);
}
               
//-------------------- Glib_SetHanCodeType Function ---------------------
//  : 0x02 0x1C 0x14 code 0x03 
// code -> 0(ϼ, default), 1()
void Glib_SetHanCodeType(unsigned char code)
{
    RsOut1(STX);
    RsOut1(0x1C);
    RsOut1(0x14);
    RsOut1(code);     
    RsOut1(ETX);
} 
               
//-------------------- Glib_OutString Function ---------------------
//  : 0x02 0x1C 0x15 StrLen String 0x03 
// StrLen -> String Length(1~100), String -> String constant                 
void Glib_OutString(flash unsigned char *str)
{              
    unsigned char i, cnt;
    
    cnt = strlenf(str);   //codevision ڿ  Ҷ
    RsOut1(STX);
    RsOut1(0x1C);
    RsOut1(0x15);    
    RsOut1(cnt);
    for(i=0 ; i<cnt ; i++)
        RsOut1(str[i]);
    RsOut1(ETX);
}                                                            


//==================================================================
//                      ׷ Լ ɱ
//==================================================================                                                                     

//-------------------- Glib_PutPixel Function ---------------------
//  : 0x02 0x1D 0x10 X Y 0x03 
// X, Y -> X, Y ǥ Ʈ    
void Glib_PutPixel(unsigned int xx, unsigned int yy)               
{
    RsOut1(STX);
    RsOut1(0x1D);
    RsOut1(0x10);    
    RsOut1((unsigned char)((xx>>8)&0xFF));
    RsOut1((unsigned char)(xx&0xFF)); 
    RsOut1((unsigned char)((yy>>8)&0xFF));
    RsOut1((unsigned char)(yy&0xFF));     
    RsOut1(ETX);                   
}

//-------------------- Glib_Line Function ---------------------
//  : 0x02 0x1D 0x11 X1 Y1 X2 Y2 0x03 
// (X1, Y1)~(X2, Y2) -> X, Y ǥ Ʈ    
void Glib_Line(unsigned int x1, unsigned int y1, unsigned int x2, unsigned int y2)               
{
    RsOut1(STX);
    RsOut1(0x1D);
    RsOut1(0x11);    
    RsOut1((unsigned char)((x1>>8)&0xFF));
    RsOut1((unsigned char)(x1&0xFF)); 
    RsOut1((unsigned char)((y1>>8)&0xFF));
    RsOut1((unsigned char)(y1&0xFF));
    RsOut1((unsigned char)((x2>>8)&0xFF));
    RsOut1((unsigned char)(x2&0xFF)); 
    RsOut1((unsigned char)((y2>>8)&0xFF));
    RsOut1((unsigned char)(y2&0xFF));              
    RsOut1(ETX);                   
}

//-------------------- Glib_Rectangle Function ---------------------
//  : 0x02 0x1D 0x12 X1 Y1 X2 Y2 0x03 
// (X1, Y1)~(X2, Y2) -> X, Y ǥ Ʈ    
void Glib_Rectangle(unsigned int x1, unsigned int y1, unsigned int x2, unsigned int y2)               
{
    RsOut1(STX);
    RsOut1(0x1D);
    RsOut1(0x12);    
    RsOut1((unsigned char)((x1>>8)&0xFF));
    RsOut1((unsigned char)(x1&0xFF)); 
    RsOut1((unsigned char)((y1>>8)&0xFF));
    RsOut1((unsigned char)(y1&0xFF));
    RsOut1((unsigned char)((x2>>8)&0xFF));
    RsOut1((unsigned char)(x2&0xFF)); 
    RsOut1((unsigned char)((y2>>8)&0xFF));
    RsOut1((unsigned char)(y2&0xFF));              
    RsOut1(ETX);                   
}

//-------------------- Glib_Circle Function ---------------------
//  : 0x02 0x1D 0x13 X0 Y0 Radius 0x03 
// (X0, Y0) -> X, Y ǥ Ʈ , Radius -> 
void Glib_Circle(unsigned int x0, unsigned int y0, unsigned char radius)               
{
    RsOut1(STX);
    RsOut1(0x1D);
    RsOut1(0x13);    
    RsOut1((unsigned char)((x0>>8)&0xFF));
    RsOut1((unsigned char)(x0&0xFF)); 
    RsOut1((unsigned char)((y0>>8)&0xFF));
    RsOut1((unsigned char)(y0&0xFF));
    RsOut1(radius);    
    RsOut1(ETX);                   
}
               
//-------------------- Glib_Ellipse Function ---------------------
//  : 0x02 0x1D 0x14 X0 Y0 a b 0x03 
// (X0, Y0) -> X, Y ǥ Ʈ  
// a -> Horizontal length, b -> Vertical length
void Glib_Ellipse(unsigned int x0, unsigned int y0, unsigned char a, unsigned char b)               
{
    RsOut1(STX);
    RsOut1(0x1D);
    RsOut1(0x14);    
    RsOut1((unsigned char)((x0>>8)&0xFF));
    RsOut1((unsigned char)(x0&0xFF)); 
    RsOut1((unsigned char)((y0>>8)&0xFF));
    RsOut1((unsigned char)(y0&0xFF));                                               
    RsOut1(a);        
    RsOut1(b);    
    RsOut1(ETX);                   
}                                      

//-------------------- Glib_Arc Function ---------------------
//  : 0x02 0x1D 0x15 X0 Y0 Radius StartAngle EndAngle 0x03 
// (X0, Y0) -> X, Y ǥ Ʈ , Radius -> 
// StartAngle -> ۰(2byte , 0~359)
// EndAngle -> (2byte , 0~359)
void Glib_Arc(unsigned int x0, unsigned int y0, unsigned char radius,
              unsigned int sAngle, unsigned int eAngle)               
{
    RsOut1(STX);
    RsOut1(0x1D);
    RsOut1(0x15);    
    RsOut1((unsigned char)((x0>>8)&0xFF));
    RsOut1((unsigned char)(x0&0xFF)); 
    RsOut1((unsigned char)((y0>>8)&0xFF));
    RsOut1((unsigned char)(y0&0xFF));
    RsOut1(radius);                  
    RsOut1((unsigned char)((sAngle>>8)&0xFF));
    RsOut1((unsigned char)(sAngle&0xFF)); 
    RsOut1((unsigned char)((eAngle>>8)&0xFF));
    RsOut1((unsigned char)(eAngle&0xFF));    
    RsOut1(ETX);                   
}
             
//-------------------- Glib_FilledRectangle Function ---------------------
//  : 0x02 0x1D 0x16 X1 Y1 X2 Y2 FillColor 0x03 
// (X1, Y1)~(X2, Y2) -> X, Y ǥ Ʈ    
// FillColor -> R G B   1Ʈ  3Ʈ      
void Glib_FilledRectangle(unsigned int x1, unsigned int y1, unsigned int x2, unsigned int y2,
                          unsigned long fillColor)               
{
    RsOut1(STX);
    RsOut1(0x1D);
    RsOut1(0x16);    
    RsOut1((unsigned char)((x1>>8)&0xFF));
    RsOut1((unsigned char)(x1&0xFF)); 
    RsOut1((unsigned char)((y1>>8)&0xFF));
    RsOut1((unsigned char)(y1&0xFF));
    RsOut1((unsigned char)((x2>>8)&0xFF));
    RsOut1((unsigned char)(x2&0xFF)); 
    RsOut1((unsigned char)((y2>>8)&0xFF));
    RsOut1((unsigned char)(y2&0xFF)); 
    RsOut1((unsigned char)((fillColor>>16)&0xFF));
    RsOut1((unsigned char)((fillColor>>8)&0xFF));
    RsOut1((unsigned char)(fillColor&0xFF));                  
    RsOut1(ETX);                   
}

//-------------------- Glib_FilledCircle Function ---------------------
//  : 0x02 0x1D 0x17 X0 Y0 Radius FillColor 0x03 
// (X0, Y0) -> X, Y ǥ Ʈ , Radius -> 
// FillColor -> R G B   1Ʈ  3Ʈ      
void Glib_FilledCircle(unsigned int x0, unsigned int y0, unsigned char radius, unsigned long fillColor)               
{
    RsOut1(STX);
    RsOut1(0x1D);
    RsOut1(0x17);    
    RsOut1((unsigned char)((x0>>8)&0xFF));
    RsOut1((unsigned char)(x0&0xFF)); 
    RsOut1((unsigned char)((y0>>8)&0xFF));
    RsOut1((unsigned char)(y0&0xFF));
    RsOut1(radius);                         
    RsOut1((unsigned char)((fillColor>>16)&0xFF));
    RsOut1((unsigned char)((fillColor>>8)&0xFF));
    RsOut1((unsigned char)(fillColor&0xFF));    
    RsOut1(ETX);                   
}

//-------------------- Glib_FilledEllipse Function ---------------------
//  : 0x02 0x1D 0x18 X0 Y0 a b FillColor 0x03 
// (X0, Y0) -> X, Y ǥ Ʈ  
// a -> Horizontal length, b -> Vertical length           
// FillColor -> R G B   1Ʈ  3Ʈ      
void Glib_FilledEllipse(unsigned int x0, unsigned int y0, unsigned char a, unsigned char b,
                        unsigned long fillColor)               
{
    RsOut1(STX);
    RsOut1(0x1D);
    RsOut1(0x18);    
    RsOut1((unsigned char)((x0>>8)&0xFF));
    RsOut1((unsigned char)(x0&0xFF)); 
    RsOut1((unsigned char)((y0>>8)&0xFF));
    RsOut1((unsigned char)(y0&0xFF));                                               
    RsOut1(a);        
    RsOut1(b);                                  
    RsOut1((unsigned char)((fillColor>>16)&0xFF));
    RsOut1((unsigned char)((fillColor>>8)&0xFF));
    RsOut1((unsigned char)(fillColor&0xFF));        
    RsOut1(ETX);                   
}

//-------------------- Glib_ClearScreen Function ---------------------
//  : 0x02 0x1D 0x19 FillColor 0x03 
// FillColor -> R G B   1Ʈ  3Ʈ      
void Glib_ClearScreen(unsigned long fillColor)               
{
    RsOut1(STX);
    RsOut1(0x1D);
    RsOut1(0x19);    
    RsOut1((unsigned char)((fillColor>>16)&0xFF));
    RsOut1((unsigned char)((fillColor>>8)&0xFF));
    RsOut1((unsigned char)(fillColor&0xFF));        
    RsOut1(ETX);                   
}

//-------------------- Glib_ClearPartialScreen Function ---------------------
//  : 0x02 0x1D 0x1A X1 Y1 X2 Y2 FillColor 0x03 
// (X1, Y1)~(X2, Y2) -> X, Y ǥ Ʈ    
// FillColor -> R G B   1Ʈ  3Ʈ      
void Glib_ClearPartialScreen(unsigned int x1, unsigned int y1, unsigned int x2, unsigned int y2,
                             unsigned long fillColor)               
{
    RsOut1(STX);
    RsOut1(0x1D);
    RsOut1(0x1A);    
    RsOut1((unsigned char)((x1>>8)&0xFF));
    RsOut1((unsigned char)(x1&0xFF)); 
    RsOut1((unsigned char)((y1>>8)&0xFF));
    RsOut1((unsigned char)(y1&0xFF));
    RsOut1((unsigned char)((x2>>8)&0xFF));
    RsOut1((unsigned char)(x2&0xFF)); 
    RsOut1((unsigned char)((y2>>8)&0xFF));
    RsOut1((unsigned char)(y2&0xFF)); 
    RsOut1((unsigned char)((fillColor>>16)&0xFF));
    RsOut1((unsigned char)((fillColor>>8)&0xFF));
    RsOut1((unsigned char)(fillColor&0xFF));                  
    RsOut1(ETX);                   
}
 
//-------------------- Glib_DisplayImage Function ---------------------
//  : 0x02 0x1D 0x1B ImageIndex X Y 0x03  
// ImageIndex -> Image Index
// X,Y -> X, Y ǥ Ʈ 
void Glib_DisplayImage(unsigned char imageIndex, unsigned int xx, unsigned int yy)               
{
    RsOut1(STX);
    RsOut1(0x1D);
    RsOut1(0x1B);                    
    RsOut1(imageIndex);
    RsOut1((unsigned char)((xx>>8)&0xFF));
    RsOut1((unsigned char)(xx&0xFF)); 
    RsOut1((unsigned char)((yy>>8)&0xFF));
    RsOut1((unsigned char)(yy&0xFF));    
    RsOut1(ETX);                   
}
       
//-------------------- Glib_PushScreen Function ---------------------
//  : 0x02 0x1D 0x1C X1 Y1 X2 Y2 0x03 
// (X1, Y1)~(X2, Y2) -> X, Y ǥ Ʈ    
void Glib_PushScreen(unsigned int x1, unsigned int y1, unsigned int x2, unsigned int y2)               
{
    RsOut1(STX);
    RsOut1(0x1D);
    RsOut1(0x1C);    
    RsOut1((unsigned char)((x1>>8)&0xFF));
    RsOut1((unsigned char)(x1&0xFF)); 
    RsOut1((unsigned char)((y1>>8)&0xFF));
    RsOut1((unsigned char)(y1&0xFF));
    RsOut1((unsigned char)((x2>>8)&0xFF));
    RsOut1((unsigned char)(x2&0xFF)); 
    RsOut1((unsigned char)((y2>>8)&0xFF));
    RsOut1((unsigned char)(y2&0xFF));              
    RsOut1(ETX);                   
}

//-------------------- Glib_PopScreen Function ---------------------
//  : 0x02 0x1D 0x1D X Y 0x03 
// X, Y -> X, Y ǥ Ʈ    
void Glib_PopScreen(unsigned int xx, unsigned int yy)               
{
    RsOut1(STX);
    RsOut1(0x1D);
    RsOut1(0x1D);    
    RsOut1((unsigned char)((xx>>8)&0xFF));
    RsOut1((unsigned char)(xx&0xFF)); 
    RsOut1((unsigned char)((yy>>8)&0xFF));
    RsOut1((unsigned char)(yy&0xFF));
    RsOut1(ETX);                   
}

//-------------------- Glib_OutUserChar Function ---------------------
//  : 0x02 0x1D 0x1E CharIndex 0x03 
// X, Y -> X, Y ǥ Ʈ    
void Glib_OutUserChar(unsigned char charIndex)               
{
    RsOut1(STX);
    RsOut1(0x1D);
    RsOut1(0x1E);    
    RsOut1(charIndex);    
    RsOut1(ETX);                   
}                       


//==================================================================
//                        Ÿ ɱ
//==================================================================                                                                     

//-------------------- Glib_TspBeepOnOff Function ---------------------
//  : 0x02 0x1E 0x14 flag 0x03 
// flag -> 0xA0(use beep), 0x0A(don't use beep, default)
void Glib_TspBeepOnOff(unsigned char flag)
{
    RsOut1(STX);
    RsOut1(0x1E);
    RsOut1(0x14);    
    RsOut1(flag);    
    RsOut1(ETX);    
}
               
//----------------------- Glib_Beep Function ------------------------
//  : 0x02 0x1E 0x14 ms 0x03 
// ms -> milli second 2byte, Ʈ 
void Glib_Beep(unsigned int ms)
{
    RsOut1(STX);
    RsOut1(0x1E);
    RsOut1(0x15);    
    RsOut1((unsigned char)((ms>>8)&0xFF));
    RsOut1((unsigned char)(ms&0xFF)); 
    RsOut1(ETX);    
}

//-------------------- Glib_OutSound Function ---------------------
//  : 0x02 0x1E 0x14 SoundIndex 0x03 
// SoundIndex -> 0~15
void Glib_OutSound(unsigned char soundIndex)
{
    RsOut1(STX);
    RsOut1(0x1E);
    RsOut1(0x16);    
    RsOut1(soundIndex);    
    RsOut1(ETX);    
}














      
