/*****************************************************
// Project : EZ-TFT700T Test Program with ATmega128
// Version : 1.0
// Date    : 2007-12-12  
// Chip type           : ATmega128
// Clock frequency     : 16.000000 MHz
// Memory model        : Small
// External SRAM size  : 0
// Data Stack size     : 1024
// Used Serial Port    : USART1
//
//  α׷ ˽ؿ EZ-TFT700(T)׽Ʈ 
// ϴ  Դϴ. ۼ Լ ٷ ̿ 
//  ְ  ؼ    ֽϴ.
// ٸ  α׷ ׽Ʈ    
//  ǰ ´ Ϻ α׷ ϴ°
// ƴմϴ. 
//   Ϻϰ Ȯϱ ؼ ̹ ε
// 10~19 ̹ ٿε Ǿ ־ ϰ  
// 0,1,2 ٿε Ǿ ־ մϴ.
*****************************************************/

#include <mega128.h>   
#include <delay.h>      
#include "glib.h"
#include "UART1.h"
         
#define SEI()   #asm("sei")     
#define LCDX    800
#define LCDY    480
#define STX     0x02
#define TSP     0x10
#define ETX     0x03

#define BLACK         0x00000000
#define BLUE          0x000000FF
#define GREEN         0x0000FF00
#define CYAN          0x0000FFFF
#define RED           0x00FF0000 
#define MAGENTA       0x00FF00FF
#define BROWN         0x00A52A2A
#define PINK          0x00FFC0CB
#define SKYBLUE       0x0087CEEB
#define YELLOW        0x00FFFF00
#define LIGHTGRAY     0x00D3D3D3
#define DARKGRAY      0x00A9A9A9
#define LIGHTBLUE     0x00ADD8E6
#define LIGHTGREEN    0x0090EE90
#define LIGHTCYAN     0x00E0FFFF
#define WHITE         0xFFFFFFFF

interrupt [TIM0_OVF] void timer0_ovf_isr(void);
void GraphicDemo(void);
void StringDemo(void);
void TspDemo(void);
void InitPort(void);    
void InitEtc(void);  
void InitTimer(void);           
unsigned long GetColor(unsigned char cl);

//----------------------------------------------------------------
//                    Main Function
//----------------------------------------------------------------
void main(void)
{
    InitPort();
    InitTimer();        
    InitUart();   
    InitEtc();
    
    SEI();
    delay_ms(1000);               
    Glib_InitLCD();       
    GraphicDemo();  
    StringDemo();
    TspDemo();
    while (1)
    {
    };
}                     

void GraphicDemo(void)
{
    unsigned long ci; 
    unsigned int x,y,i;
    unsigned char c;
      
    //---------------- Line Demo ----------------
    c = 0;
    for(y=0 ; y<160 ; y++ )               
    {           
        ci = c+95;           
        Glib_SetLineColor(ci<<16);
        Glib_Line(0,y,799,y);
        c++;
    }     
    c = 0;    
    for(y=160 ; y<320 ; y++ )               
    {           
        ci = c+95;           
        Glib_SetLineColor(ci<<8);
        Glib_Line(0,y,799,y);
        c++;
    }     
    c = 0;    
    for(y=320 ; y<LCDY ; y++ )               
    {           
        ci = c+95;           
        Glib_SetLineColor(ci);
        Glib_Line(0,y,799,y);
        c++;
    }    
    Glib_Beep(200); 
    
    //---------------- Rectangle Demo ----------------    
    Glib_ClearScreen(WHITE);
	for(i=0 ; i<200 ; i++ )
	{
		Glib_SetLineColor(GetColor(i%16));
		Glib_Rectangle(400-i, 240-i,  420+i, 250+i);
	}    
    Glib_Beep(200);  
                              
    //---------------- Circle Demo ----------------    	
    Glib_ClearScreen(WHITE);            
	for(i=0 ; i<200 ; i++ )
	{
		Glib_SetLineColor(GetColor(i%16));
		Glib_Circle(400, 240, i);
	}
    Glib_Beep(200);
    
    //---------------- Ellipse Demo ----------------    	
    Glib_ClearScreen(WHITE);            
	for(i=0 ; i<200 ; i++ )
	{
		Glib_SetLineColor(GetColor(i%16));
		Glib_Ellipse(400, 240, i+50, i+10);
	}
    Glib_Beep(200);	
    
    //---------------- FilledRectangle Demo ----------------    	
    Glib_ClearScreen(WHITE);    
	for(i=0 ; i<200 ; i+=2 )
	{
		Glib_FilledRectangle(i,i,599+i,i+279,GetColor(i%16));
		delay_ms(10);
	}    
    Glib_Beep(200);	 
                     
    //---------------- FilledCircle Demo ----------------    	
    Glib_ClearScreen(WHITE);    
	for(i=0 ; i<200 ; i+=2 )
	{
		Glib_FilledCircle(400, 240, 200-i,GetColor(i%16));
		delay_ms(20);		
	}    	                           
    Glib_Beep(200);
    	                  
    //---------------- FilledEllipse Demo ----------------    	
    Glib_ClearScreen(WHITE);            
	for(i=0 ; i<200 ; i+=2 )
	{
		Glib_FilledEllipse(400, 240, 200-i+40, 200-i+2, GetColor(i%16));
		delay_ms(20);
	} 
    Glib_Beep(200);
    	
    //---------------- DisplayImage Demo ----------------	
    for(i=10 ; i<20 ; i++ )
    {
        Glib_DisplayImage(i, 0, 0);
        delay_ms(500);
    }	
    delay_ms(1500);      
    Glib_Beep(200);
        
    //---------------- Screen Push/Pop Demo ----------------	    
    Glib_PushScreen(0,0,400,240);
    Glib_ClearScreen(WHITE);
    delay_ms(800);
    Glib_PopScreen(400,0);
    delay_ms(800);
    Glib_PopScreen(400,240);
    delay_ms(800);
    Glib_PopScreen(0,240);
    delay_ms(800);    
    Glib_PopScreen(0,0);    
    delay_ms(800);                                                 
    Glib_Beep(200);
    
    //---------------- User Char Demo ----------------
    Glib_ClearScreen(WHITE);                
    for(y=0 ; y<30 ; y++ )
    {
        Glib_SetLocate(0,y*16);
        for(x=0 ; x<50 ; x++)
            Glib_OutUserChar(y%3);
        delay_ms(60); 
    }
    Glib_Beep(200);  
                     
    //---------------- BackLight On/Off Demo ----------------
    Glib_LcdBackLight(0x0A);
    delay_ms(500);
    Glib_LcdBackLight(0xA0);                            
    delay_ms(500);    
    Glib_LcdBackLight(0x0A);
    delay_ms(500);    
    Glib_LcdBackLight(0xA0);        
    Glib_Beep(200);      
}

void StringDemo(void)
{           
    unsigned int i,j,zr;
    
    zr=1;
    for(i=0 ; i<10 ; i++)
    {
        Glib_ClearScreen(WHITE);
        Glib_SetLocate(0,0);            
        Glib_SetHangulFont(i%5);
        if(i>4)
            zr=2;
        Glib_SetZoomRate(zr);      
        Glib_SetFontColor(GetColor(i),WHITE);
        switch(i)
        {  
            case 0 :
            case 5 : Glib_OutString("1.ѱ۸1"); 
                     break;
            case 1 :
            case 6 : Glib_OutString("2.ѱ۸"); 
                     break;
            case 2 :
            case 7 : Glib_OutString("3.ѱ۰°"); 
                     break;
            case 3 :
            case 8 : Glib_OutString("4.ѱ۱"); 
                     break;
            case 4 :
            case 9 : Glib_OutString("5.ѱʱü"); 
                     break;                                                               
        }
        for(j=0 ; j<10 ; j++)
        {
            Glib_SetLocate(0,16*(j+2)*zr);
            Glib_OutString("ѱ ׽Ʈ Դϴ.");   
        } 
        delay_ms(500);        
    }    
     
    zr=1;
    for(i=0 ; i<10 ; i++)
    {
        Glib_ClearScreen(WHITE);
        Glib_SetLocate(0,0);            
        Glib_SetEnglishFont(i%5);
        if(i>4)
            zr=2;
        Glib_SetZoomRate(zr);
        Glib_SetFontColor(GetColor(i),WHITE);        
        switch(i)
        {  
            case 0 :
            case 5 : Glib_OutString("1.1"); 
                     break;
            case 1 :
            case 6 : Glib_OutString("2.2"); 
                     break;
            case 2 :
            case 7 : Glib_OutString("3.θ"); 
                     break;
            case 3 :
            case 8 : Glib_OutString("4."); 
                     break;
            case 4 :
            case 9 : Glib_OutString("5.ü"); 
                     break;                                                               
        }
        for(j=0 ; j<10 ; j++)
        {
            Glib_SetLocate(0,16*(j+2)*zr);
            Glib_OutString("This is English font demonstration.");
        }       
        delay_ms(500);             
    }    
}                                                              

//-------------------- TspDemo Function ---------------------        
void TspDemo(void)
{
    unsigned char rxcnt, b, sflow, rxBuf[5];            
    unsigned int x, y;
            
    Glib_TspOnOff(0xA0);     // TSP On       
    Glib_SetTspMode(0x0A);   // Down only
    Glib_TspBeepOnOff(0xA0); // Beep On
    
    Glib_ClearScreen(WHITE);                                           
    Glib_SetLineColor(BLACK);
    Glib_SetLineWidth(2);           
    Glib_SetFontColor(BLACK, WHITE);
    Glib_SetLocate(10,0);
    Glib_OutString("<TSP TEST>");
    sflow = 100;
    while(1)
    {
        if(RsReady1())
        {                    
            b = RsIn1();       
            switch(sflow)
            {
                case 100 : if(b==STX)
                               sflow = 200;
                           break;
                case 200 : if(b==TSP)      
                           {
                               sflow = 300;
                               rxcnt = 0;
                           }
                           else
                               sflow = 100;
                           break;          
                case 300 : rxBuf[rxcnt++] = b;
                           if(rxcnt>=5)
                               sflow = 400;
                           break;
                case 400 : if(b==ETX)
                           {     
                               x = (unsigned int)rxBuf[0]*256+rxBuf[1];
                               y = (unsigned int)rxBuf[2]*256+rxBuf[3];
                               if((x<LCDX) && (y<LCDY))
                               {
                                   Glib_Line(x-10,y,x+10,y);
                                   Glib_Line(x,y-10,x,y+10); 
                               }
                           }
                           sflow = 100;
                           break;
            }
        }             
    }
}

//--------------------------------------------------------------
//             Timer0 Interrupt Service Routine
//--------------------------------------------------------------
interrupt [TIM0_OVF] void timer0_ovf_isr(void)
{
// Place your code here
}

//-------------------- InitTimer Function ---------------------
void InitTimer(void)
{
    // Timer/Counter 0 initialization
    // Clock value: 125.000 kHz
    ASSR=0x00; TCCR0=0x05; TCNT0=0x00; OCR0=0x00;

    // Timer/Counter 1 initialization
    TCCR1A=0x00; TCCR1B=0x00; TCNT1H=0x00; TCNT1L=0x00;
    ICR1H=0x00; ICR1L=0x00;
    OCR1AH=0x00; OCR1AL=0x00; OCR1BH=0x00; OCR1BL=0x00; OCR1CH=0x00; OCR1CL=0x00;

    // Timer/Counter 2 initialization
    TCCR2=0x00; TCNT2=0x00; OCR2=0x00;

    // Timer/Counter 3 initialization
    TCCR3A=0x00; TCCR3B=0x00; TCNT3H=0x00; TCNT3L=0x00;
    ICR3H=0x00; ICR3L=0x00;
    OCR3AH=0x00; OCR3AL=0x00; OCR3BH=0x00; OCR3BL=0x00; OCR3CH=0x00; OCR3CL=0x00;

    // Timer(s)/Counter(s) Interrupt(s) initialization
    TIMSK=0x01;  ETIMSK=0x00;    
}
                                               
//-------------------- InitPort Function ----------------------
void InitPort(void)
{
    PORTA=0x00; DDRA=0x00;
    PORTB=0x00; DDRB=0x00;
    PORTC=0x00; DDRC=0x00;
    PORTD=0x08; DDRD=0x08;
    PORTE=0x00; DDRE=0x00;
    PORTF=0x00; DDRF=0x00;
    PORTG=0x00; DDRG=0x00;
}       

//-------------------- InitEtc Function ----------------------
void InitEtc(void)
{
    // External Interrupt(s) initialization
    EICRA=0x00; EICRB=0x00; EIMSK=0x00;
    // Analog Comparator initialization
    ACSR=0x80; SFIOR=0x00;
}       

//-------------------- GetColor Function ----------------------                                                             
unsigned long GetColor(unsigned char cl)
{
	unsigned long clcl;
	
	switch(cl)
	{
		case 0 : clcl = BLACK; break;
		case 1 : clcl = BLUE; break;
		case 2 : clcl = GREEN; break;
		case 3 : clcl = CYAN; break;
		case 4 : clcl = RED; break;
		case 5 : clcl = MAGENTA; break;
		case 6 : clcl = BROWN; break;
		case 7 : clcl = PINK; break;		
		case 8 : clcl = SKYBLUE; break;												
		case 9 : clcl = YELLOW; break;		
		case 10: clcl = LIGHTGRAY; break;		
		case 11: clcl = DARKGRAY; break;		
		case 12: clcl = LIGHTBLUE; break;		
		case 13: clcl = LIGHTGREEN; break;		
		case 14: clcl = LIGHTCYAN; break;		
		case 15: clcl = WHITE; break;		
	}		    
	return(clcl);
}


            

