/*****************************************************
Project : EZ-TFT700T Test Program with ATmega128
Version : 
Date    : 2007-  -  
Comments: 
Chip type           : ATmega128
Clock frequency     : 16.000000 MHz
Memory model        : Small
External SRAM size  : 0
Data Stack size     : 1024
*****************************************************/

#include <mega128.h>   
#include <delay.h>      
#include "glib.h"
#include "UART1.h"
         
#define SEI()   #asm("sei")     
#define LCDX    800
#define LCDY    480
#define STX     0x02
#define TSP     0x10
#define ETX     0x03

#define BLACK         0x00000000
#define BLUE          0x000000FF
#define GREEN         0x0000FF00
#define CYAN          0x0000FFFF
#define RED           0x00FF0000 
#define MAGENTA       0x00FF00FF
#define BROWN         0x00A52A2A
#define PINK          0x00FFC0CB
#define SKYBLUE       0x0087CEEB
#define YELLOW        0x00FFFF00
#define LIGHTGRAY     0x00D3D3D3
#define DARKGRAY      0x00A9A9A9
#define LIGHTBLUE     0x00ADD8E6
#define LIGHTGREEN    0x0090EE90
#define LIGHTCYAN     0x00E0FFFF
#define WHITE         0xFFFFFFFF

interrupt [TIM0_OVF] void timer0_ovf_isr(void);
void GraphicDemo(void);
void StringDemo(void);
void TspDemo(void);
void InitPort(void);    
void InitEtc(void);  
void InitTimer(void);           
unsigned long GetColor(unsigned char cl);

//----------------------------------------------------------------
//                    Main Function
//----------------------------------------------------------------
void main(void)
{
    InitPort();
    InitTimer();        
    InitUart();   
    InitEtc();
    
    SEI();
    delay_ms(1000);               
    Glib_InitLCD();       
    GraphicDemo();  
    StringDemo();
    TspDemo();
    while (1)
    {
      // 1. Graphic Demo
      // 2. String Demo
      // 3. TSP Demo  -> Open   (ġ ǥ ׷ ǥ)
      //
    };
}                     

void GraphicDemo(void)
{
    unsigned long ci; 
    unsigned int x,y,i;
    unsigned char c;
      
    //---------------- Line Demo ----------------
    c = 0;
    for(y=0 ; y<160 ; y++ )               
    {           
        ci = c+95;           
        Glib_SetLineColor(ci<<16);
        Glib_Line(0,y,799,y);
        c++;
    }     
    c = 0;    
    for(y=160 ; y<320 ; y++ )               
    {           
        ci = c+95;           
        Glib_SetLineColor(ci<<8);
        Glib_Line(0,y,799,y);
        c++;
    }     
    c = 0;    
    for(y=320 ; y<LCDY ; y++ )               
    {           
        ci = c+95;           
        Glib_SetLineColor(ci);
        Glib_Line(0,y,799,y);
        c++;
    }    
    Glib_Beep(200);
    //---------------- Rectangle Demo ----------------    
    Glib_ClearScreen(WHITE);
	for(i=0 ; i<200 ; i++ )
	{
		Glib_SetLineColor(GetColor(i%16));
		Glib_Rectangle(400-i, 240-i,  420+i, 250+i);
	}    
    Glib_Beep(200);                            
    //---------------- Circle Demo ----------------    	
    Glib_ClearScreen(WHITE);            
	for(i=0 ; i<200 ; i++ )
	{
		Glib_SetLineColor(GetColor(i%16));
		Glib_Circle(400, 240, i);
	}
    Glib_Beep(200);
    //---------------- Ellipse Demo ----------------    	
    Glib_ClearScreen(WHITE);            
	for(i=0 ; i<200 ; i++ )
	{
		Glib_SetLineColor(GetColor(i%16));
		Glib_Ellipse(400, 240, i+50, i+10);
	}
    Glib_Beep(200);	
    //---------------- FilledRectangle Demo ----------------    	
    Glib_ClearScreen(WHITE);    
	for(i=0 ; i<200 ; i+=2 )
	{
		Glib_FilledRectangle(i,i,599+i,i+279,GetColor(i%16));
		delay_ms(10);
	}    
    Glib_Beep(200);	                  
    //---------------- FilledCircle Demo ----------------    	
    Glib_ClearScreen(WHITE);    
	for(i=0 ; i<200 ; i+=2 )
	{
		Glib_FilledCircle(400, 240, 200-i,GetColor(i%16));
		delay_ms(20);		
	}    	                           
    Glib_Beep(200);
    	                  
    //---------------- FilledEllipse Demo ----------------    	
    Glib_ClearScreen(WHITE);            
	for(i=0 ; i<200 ; i+=2 )
	{
		Glib_FilledEllipse(400, 240, 200-i+40, 200-i+2, GetColor(i%16));
		delay_ms(20);
	} 
    Glib_Beep(200);
    	
    //---------------- DisplayImage Demo ----------------	
    for(i=10 ; i<20 ; i++ )
    {
        Glib_DisplayImage(i, 0, 0);
        delay_ms(500);
    }	
    delay_ms(1500);      
    Glib_Beep(200);
        
    //---------------- Screen Push/Pop Demo ----------------	    
    Glib_PushScreen(0,0,400,240);
    Glib_ClearScreen(WHITE);
    delay_ms(800);
    Glib_PopScreen(400,0);
    delay_ms(800);
    Glib_PopScreen(400,240);
    delay_ms(800);
    Glib_PopScreen(0,240);
    delay_ms(800);    
    Glib_PopScreen(0,0);    
    delay_ms(800);                                                 
    Glib_Beep(200);
    
    //---------------- User Char Demo ----------------
    Glib_ClearScreen(WHITE);                
    for(y=0 ; y<30 ; y++ )
    {
        Glib_SetLocate(0,y*16);
        for(x=0 ; x<50 ; x++)
            Glib_OutUserChar(y%3);
        delay_ms(60); 
    }
    Glib_Beep(200);
    Glib_LcdBackLight(0x0A);
    delay_ms(500);
    Glib_LcdBackLight(0xA0);                            
    delay_ms(500);    
    Glib_LcdBackLight(0x0A);
    delay_ms(500);    
    Glib_LcdBackLight(0xA0);        
}

void StringDemo(void)
{           
    unsigned int i,j,zr;
    
    zr=1;
    for(i=0 ; i<10 ; i++)
    {
        Glib_ClearScreen(WHITE);
        Glib_SetLocate(0,0);            
        Glib_SetHangulFont(i%5);
        if(i>4)
            zr=2;
        Glib_SetZoomRate(zr);      
        Glib_SetFontColor(GetColor(i),WHITE);
        switch(i)
        {  
            case 0 :
            case 5 : Glib_OutString("1.ѱ۸1"); 
                     break;
            case 1 :
            case 6 : Glib_OutString("2.ѱ۸"); 
                     break;
            case 2 :
            case 7 : Glib_OutString("3.ѱ۰°"); 
                     break;
            case 3 :
            case 8 : Glib_OutString("4.ѱ۱"); 
                     break;
            case 4 :
            case 9 : Glib_OutString("5.ѱʱü"); 
                     break;                                                               
        }
        for(j=0 ; j<10 ; j++)
        {
            Glib_SetLocate(0,16*(j+2)*zr);
            Glib_OutString("ѱ ׽Ʈ Դϴ.");   
        } 
        delay_ms(500);        
    }    
     
    zr=1;
    for(i=0 ; i<10 ; i++)
    {
        Glib_ClearScreen(WHITE);
        Glib_SetLocate(0,0);            
        Glib_SetEnglishFont(i%5);
        if(i>4)
            zr=2;
        Glib_SetZoomRate(zr);
        Glib_SetFontColor(GetColor(i),WHITE);        
        switch(i)
        {  
            case 0 :
            case 5 : Glib_OutString("1.1"); 
                     break;
            case 1 :
            case 6 : Glib_OutString("2.2"); 
                     break;
            case 2 :
            case 7 : Glib_OutString("3.θ"); 
                     break;
            case 3 :
            case 8 : Glib_OutString("4."); 
                     break;
            case 4 :
            case 9 : Glib_OutString("5.ü"); 
                     break;                                                               
        }
        for(j=0 ; j<10 ; j++)
        {
            Glib_SetLocate(0,16*(j+2)*zr);
            Glib_OutString("This is English font demonstration.");
        }       
        delay_ms(500);             
    }    
}                                                              

//-------------------- TspDemo Function ---------------------        
void TspDemo(void)
{
    unsigned char rxcnt, b, sflow, rxBuf[5];            
    unsigned int x, y;
            
    Glib_TspOnOff(0xA0);     // TSP On       
    Glib_SetTspMode(0x0A);   // Down only
    Glib_TspBeepOnOff(0xA0); // Beep On
    
    Glib_ClearScreen(WHITE);                                           
    Glib_SetLineColor(BLACK);
    Glib_SetLineWidth(2);           
    Glib_SetFontColor(BLACK, WHITE);
    Glib_SetLocate(10,0);
    Glib_OutString("<TSP TEST>");
    sflow = 100;
    while(1)
    {
        if(RsReady1())
        {                    
            b = RsIn1();       
            switch(sflow)
            {
                case 100 : if(b==STX)
                               sflow = 200;
                           break;
                case 200 : if(b==TSP)      
                           {
                               sflow = 300;
                               rxcnt = 0;
                           }
                           else
                               sflow = 100;
                           break;          
                case 300 : rxBuf[rxcnt++] = b;
                           if(rxcnt>=5)
                               sflow = 400;
                           break;
                case 400 : if(b==ETX)
                           {     
                               x = (unsigned int)rxBuf[0]*256+rxBuf[1];
                               y = (unsigned int)rxBuf[2]*256+rxBuf[3];
                               if((x<LCDX) && (y<LCDY))
                               {
                                   Glib_Line(x-10,y,x+10,y);
                                   Glib_Line(x,y-10,x,y+10); 
                               }
                           }
                           sflow = 100;
                           break;
            }
        }             
    }
}

//--------------------------------------------------------------
//             Timer0 Interrupt Service Routine
//--------------------------------------------------------------
interrupt [TIM0_OVF] void timer0_ovf_isr(void)
{
// Place your code here
}

//-------------------- InitTimer Function ---------------------
void InitTimer(void)
{
    // Timer/Counter 0 initialization
    // Clock value: 125.000 kHz
    ASSR=0x00; TCCR0=0x05; TCNT0=0x00; OCR0=0x00;

    // Timer/Counter 1 initialization
    TCCR1A=0x00; TCCR1B=0x00; TCNT1H=0x00; TCNT1L=0x00;
    ICR1H=0x00; ICR1L=0x00;
    OCR1AH=0x00; OCR1AL=0x00; OCR1BH=0x00; OCR1BL=0x00; OCR1CH=0x00; OCR1CL=0x00;

    // Timer/Counter 2 initialization
    TCCR2=0x00; TCNT2=0x00; OCR2=0x00;

    // Timer/Counter 3 initialization
    TCCR3A=0x00; TCCR3B=0x00; TCNT3H=0x00; TCNT3L=0x00;
    ICR3H=0x00; ICR3L=0x00;
    OCR3AH=0x00; OCR3AL=0x00; OCR3BH=0x00; OCR3BL=0x00; OCR3CH=0x00; OCR3CL=0x00;

    // Timer(s)/Counter(s) Interrupt(s) initialization
    TIMSK=0x01;  ETIMSK=0x00;    
}
                                               
//-------------------- InitPort Function ----------------------
void InitPort(void)
{
    PORTA=0x00; DDRA=0x00;
    PORTB=0x00; DDRB=0x00;
    PORTC=0x00; DDRC=0x00;
    PORTD=0x08; DDRD=0x08;
    PORTE=0x00; DDRE=0x00;
    PORTF=0x00; DDRF=0x00;
    PORTG=0x00; DDRG=0x00;
}       

//-------------------- InitEtc Function ----------------------
void InitEtc(void)
{
    // External Interrupt(s) initialization
    EICRA=0x00; EICRB=0x00; EIMSK=0x00;
    // Analog Comparator initialization
    ACSR=0x80; SFIOR=0x00;
}       

//-------------------- GetColor Function ----------------------                                                             
unsigned long GetColor(unsigned char cl)
{
	unsigned long clcl;
	
	switch(cl)
	{
		case 0 : clcl = BLACK; break;
		case 1 : clcl = BLUE; break;
		case 2 : clcl = GREEN; break;
		case 3 : clcl = CYAN; break;
		case 4 : clcl = RED; break;
		case 5 : clcl = MAGENTA; break;
		case 6 : clcl = BROWN; break;
		case 7 : clcl = PINK; break;		
		case 8 : clcl = SKYBLUE; break;												
		case 9 : clcl = YELLOW; break;		
		case 10: clcl = LIGHTGRAY; break;		
		case 11: clcl = DARKGRAY; break;		
		case 12: clcl = LIGHTBLUE; break;		
		case 13: clcl = LIGHTGREEN; break;		
		case 14: clcl = LIGHTCYAN; break;		
		case 15: clcl = WHITE; break;		
	}		    
	return(clcl);
}


            

#include "UART1.h"
                   
#define SEI()   #asm("sei")

#define RXB8 1
#define TXB8 0
#define UPE  2
#define OVR  3
#define FE   4
#define UDRE 5
#define RXC  7

#define FRAMING_ERROR (1<<FE)
#define PARITY_ERROR (1<<UPE)
#define DATA_OVERRUN (1<<OVR)
#define DATA_REGISTER_EMPTY (1<<UDRE)
#define RX_COMPLETE (1<<RXC)
#define RX_BUFFER_SIZE1 128

// USART1 Receiver buffer & Variables
unsigned char rx_buffer1[RX_BUFFER_SIZE1];
unsigned char rx_wr_index1,rx_rd_index1,rx_counter1;
bit rx_buffer_overflow1;

//----------------- UART1 Receive ISR ----------------------------
interrupt [USART1_RXC] void usart1_rx_isr(void)
{
    unsigned char status,data;
    status=UCSR1A;
    data = UDR1;
    
//    if ((status & (FRAMING_ERROR | PARITY_ERROR | DATA_OVERRUN))==0)
//   {
       rx_buffer1[rx_wr_index1]=data;
       if (++rx_wr_index1 == RX_BUFFER_SIZE1) 
           rx_wr_index1=0;
       if (++rx_counter1 == RX_BUFFER_SIZE1)
      {
          rx_counter1=0;
          rx_buffer_overflow1=1;
      }
//   }    
}                                     

//----------------- UART1 RsIn1 Function ------------------------
unsigned char RsIn1(void)
{
    char data;
    data=rx_buffer1[rx_rd_index1];
    if (++rx_rd_index1 == RX_BUFFER_SIZE1) 
        rx_rd_index1=0;
    #asm("cli")
    --rx_counter1;
    #asm("sei")
    return data;
}                          

//----------------- UART1 RsReady1 Function ---------------------
unsigned char RsReady1(void)
{
    if(rx_counter1>0)
        return(1);
    else
        return(0);        
}                 
                                              
//----------------- UART1 RsOut1 Function ----------------------
void RsOut1(char c)
{
    while ((UCSR1A & DATA_REGISTER_EMPTY)==0);
    UDR1=c;
}

//----------------- UART1 InitUart Function ----------------------
void InitUart(void)
{
    // USART1 initialization, 19200bps 8N1
    UCSR1A=0x00; UCSR1B=0x98; UCSR1C=0x06; UBRR1H=0x00; UBRR1L=0x33;
    UCSR0A=0x00; UCSR0B=0x98; UCSR0C=0x06; UBRR1H=0x00; UBRR0L=0x33;    
}
#include <string.h>
#include "UART1.h"
#include "GLIB.h"                            

             
#define STX 0x02
#define ETX 0x03       

//==================================================================
//                     LCD  ɱ
//==================================================================

//--------------------- Glib_InitLCD Function ----------------------
//  : 0x02 0x1A 0x10 0x03
void Glib_InitLCD(void)
{
    RsOut1(STX);
    RsOut1(0x1A);
    RsOut1(0x10);
    RsOut1(ETX);
}

//-------------------- Glib_SetBaudRate Function --------------------
//  : 0x02 0x1A 0x11 br 0x03
// 1200bps -> 0,  2400bps -> 1,  4800bps -> 2, 9600bps ->3
// 19200bps -> 4(Default), 38400bps -> 5, 57600bps -> 6, 115200bps -> 7
void Glib_SetBaudRate(unsigned char br)
{
    RsOut1(STX);
    RsOut1(0x1A);
    RsOut1(0x11);
    RsOut1(br);    
    RsOut1(ETX);    
}                                         

//--------------------- Glib_TspOnOff Function ----------------------
//  : 0x02 0x1A 0x12 flag 0x03
// flag: 0xA0->ON,  0x0A->OFF(Default)
void Glib_TspOnOff(unsigned char flag)
{
    RsOut1(STX);
    RsOut1(0x1A);
    RsOut1(0x12);
    RsOut1(flag);    
    RsOut1(ETX);   
}
 
//-------------------- Glib_SetTspMode Function ---------------------
//  : 0x02 0x1A 0x13 flag 0x03
// flag: 0xA0->Up/Down Event(Default),  0x0A->Down Event only
void Glib_SetTspMode(unsigned char flag)
{
    RsOut1(STX);
    RsOut1(0x1A);
    RsOut1(0x13);
    RsOut1(flag);    
    RsOut1(ETX);   
}

//------------------- Glib_LcdBackLight Function --------------------
//  : 0x02 0x1A 0x14 flag 0x03
// flag: 0xA0->On,  0x0A->Off(default)
void Glib_LcdBackLight(unsigned char flag)
{
    RsOut1(STX);
    RsOut1(0x1A);
    RsOut1(0x14);
    RsOut1(flag);    
    RsOut1(ETX);   
}

//---------------- Glib_SetFullDisplayMode Function -----------------
//  : 0x02 0x1A 0x15 flag 0x03
// flag: 0xA0->use PCI function(default),  0x0A->don't use PCI function
void Glib_SetFullDisplayMode(unsigned char flag)
{
    RsOut1(STX);
    RsOut1(0x15);
    RsOut1(0x14);
    RsOut1(flag);    
    RsOut1(ETX);   
}

         
//==================================================================
//                      ׷  ɱ
//==================================================================                                                                     

//------------------ Glib_SetHangulFont Function -------------------
//  : 0x02 0x1B 0x10 hIndex 0x03
// hIndex: ѱ۸1->0(default), ѱ۸2->1, ѱ۰°->2
//         ѱ۱->3, ѱʱü->4          
void Glib_SetHangulFont(unsigned char hIndex)
{
    RsOut1(STX);
    RsOut1(0x1B);
    RsOut1(0x10);
    RsOut1(hIndex);    
    RsOut1(ETX);   
}
 
//------------------ Glib_SetEnglishFont Function -------------------
//  : 0x02 0x1B 0x11 eIndex 0x03
// hIndex: 1->0(default), 2->1, θ->2
//         ->3, ü->4          
void Glib_SetEnglishFont(unsigned char eIndex)
{
    RsOut1(STX);
    RsOut1(0x1B);
    RsOut1(0x11);
    RsOut1(eIndex);    
    RsOut1(ETX);   
}

 
//------------------ Glib_SetFontColor Function -------------------
//  : 0x02 0x1B 0x12 ForeColor BackColor 0x03
// ForeColor, Backcolor -> R G B   1Ʈ  3Ʈ 
// Default -> ForeColor:Black, BackColor=White
void Glib_SetFontColor(unsigned long fColor, unsigned long bColor)
{
    RsOut1(STX);
    RsOut1(0x1B);
    RsOut1(0x12);
    RsOut1((unsigned char)((fColor>>16)&0xFF));
    RsOut1((unsigned char)((fColor>>8)&0xFF));
    RsOut1((unsigned char)(fColor&0xFF)); 
    RsOut1((unsigned char)((bColor>>16)&0xFF));
    RsOut1((unsigned char)((bColor>>8)&0xFF));
    RsOut1((unsigned char)(bColor&0xFF)); 
    RsOut1(ETX);   
}

//------------------ Glib_SetLineColor Function -------------------
//  : 0x02 0x1B 0x13 LineColor 0x03
// LineColor -> R G B   1Ʈ  3Ʈ      
// Default -> Black
void Glib_SetLineColor(unsigned long lineColor)
{
    RsOut1(STX);
    RsOut1(0x1B);
    RsOut1(0x13);
    RsOut1((unsigned char)((lineColor>>16)&0xFF));
    RsOut1((unsigned char)((lineColor>>8)&0xFF));
    RsOut1((unsigned char)(lineColor&0xFF)); 
    RsOut1(ETX);   
} 

//------------------ Glib_SetLineWidth Function -------------------
//  : 0x02 0x1B 0x14 LineWidth 0x03
// LineWidth -> 1~7 (default=1)
void Glib_SetLineWidth(unsigned char lineWidth)
{
    RsOut1(STX);
    RsOut1(0x1B);
    RsOut1(0x14);
    RsOut1(lineWidth); 
    RsOut1(ETX);   
}   


//==================================================================
//                      Ʈ ɱ
//==================================================================                                                                     

//-------------------- Glib_SetLocate Function ---------------------
//  : 0x02 0x1C 0x10 Xposition Yposition 0x03 
// Xposition, Yposition -> X, Y ǥ Ʈ    
// Default -> (0, 0)
void Glib_SetLocate(unsigned int xx, unsigned int yy)
{
    RsOut1(STX);
    RsOut1(0x1C);
    RsOut1(0x10);
    RsOut1((unsigned char)((xx>>8)&0xFF));
    RsOut1((unsigned char)(xx&0xFF)); 
    RsOut1((unsigned char)((yy>>8)&0xFF));
    RsOut1((unsigned char)(yy&0xFF));     
    RsOut1(ETX);
}               

//-------------------- Glib_SetZoomRate Function ---------------------
//  : 0x02 0x1C 0x11 ZoomRate 0x03 
// ZoomRate -> 1(default) or 2;     680 void Glib_SetZoomRate(unsigned char zoomRate)
{
    RsOut1(STX);
    RsOut1(0x1C);
    RsOut1(0x11);
    RsOut1(zoomRate);     
    RsOut1(ETX);
}                  

//-------------------- Glib_FontBackMode Function ---------------------
//  : 0x02 0x1C 0x12 flag 0x03 
// flag -> 0xA0(use background font color, default), 0x0A(don't use)
void Glib_FontBackMode(unsigned char flag)
{
    RsOut1(STX);
    RsOut1(0x1C);
    RsOut1(0x12);
    RsOut1(flag);     
    RsOut1(ETX);
}                  
 
//-------------------- Glib_CursorOnOff Function ---------------------
//  : 0x02 0x1C 0x13 flag 0x03 
// flag -> 0xA0(cursor on), 0x0A(cursor off, default)
void Glib_CursorOnOff(unsigned char flag)
{
    RsOut1(STX);
    RsOut1(0x1C);
    RsOut1(0x13);
    RsOut1(flag);     
    RsOut1(ETX);
}
               
//-------------------- Glib_SetHanCodeType Function ---------------------
//  : 0x02 0x1C 0x14 code 0x03 
// code -> 0(ϼ, default), 1()
void Glib_SetHanCodeType(unsigned char code)
{
    RsOut1(STX);
    RsOut1(0x1C);
    RsOut1(0x14);
    RsOut1(code);     
    RsOut1(ETX);
} 
               
//-------------------- Glib_OutString Function ---------------------
//  : 0x02 0x1C 0x15 StrLen String 0x03 
// StrLen -> String Length(1~100), String -> String constant                 
void Glib_OutString(flash unsigned char *str)
{              
    unsigned char i, cnt;
    
    cnt = strlenf(str);   //codevision ڿ  Ҷ
    RsOut1(STX);
    RsOut1(0x1C);
    RsOut1(0x15);    
    RsOut1(cnt);
    for(i=0 ; i<cnt ; i++)
        RsOut1(str[i]);
    RsOut1(ETX);
}                                                            


//==================================================================
//                      ׷ Լ ɱ
//==================================================================                                                                     

//-------------------- Glib_PutPixel Function ---------------------
//  : 0x02 0x1D 0x10 X Y 0x03 
// X, Y -> X, Y ǥ Ʈ    
void Glib_PutPixel(unsigned int xx, unsigned int yy)               
{
    RsOut1(STX);
    RsOut1(0x1D);
    RsOut1(0x10);    
    RsOut1((unsigned char)((xx>>8)&0xFF));
    RsOut1((unsigned char)(xx&0xFF)); 
    RsOut1((unsigned char)((yy>>8)&0xFF));
    RsOut1((unsigned char)(yy&0xFF));     
    RsOut1(ETX);                   
}

//-------------------- Glib_Line Function ---------------------
//  : 0x02 0x1D 0x11 X1 Y1 X2 Y2 0x03 
// (X1, Y1)~(X2, Y2) -> X, Y ǥ Ʈ    
void Glib_Line(unsigned int x1, unsigned int y1, unsigned int x2, unsigned int y2)               
{
    RsOut1(STX);
    RsOut1(0x1D);
    RsOut1(0x11);    
    RsOut1((unsigned char)((x1>>8)&0xFF));
    RsOut1((unsigned char)(x1&0xFF)); 
    RsOut1((unsigned char)((y1>>8)&0xFF));
    RsOut1((unsigned char)(y1&0xFF));
    RsOut1((unsigned char)((x2>>8)&0xFF));
    RsOut1((unsigned char)(x2&0xFF)); 
    RsOut1((unsigned char)((y2>>8)&0xFF));
    RsOut1((unsigned char)(y2&0xFF));              
    RsOut1(ETX);                   
}

//-------------------- Glib_Rectangle Function ---------------------
//  : 0x02 0x1D 0x12 X1 Y1 X2 Y2 0x03 
// (X1, Y1)~(X2, Y2) -> X, Y ǥ Ʈ    
void Glib_Rectangle(unsigned int x1, unsigned int y1, unsigned int x2, unsigned int y2)               
{
    RsOut1(STX);
    RsOut1(0x1D);
    RsOut1(0x12);    
    RsOut1((unsigned char)((x1>>8)&0xFF));
    RsOut1((unsigned char)(x1&0xFF)); 
    RsOut1((unsigned char)((y1>>8)&0xFF));
    RsOut1((unsigned char)(y1&0xFF));
    RsOut1((unsigned char)((x2>>8)&0xFF));
    RsOut1((unsigned char)(x2&0xFF)); 
    RsOut1((unsigned char)((y2>>8)&0xFF));
    RsOut1((unsigned char)(y2&0xFF));              
    RsOut1(ETX);                   
}

//-------------------- Glib_Circle Function ---------------------
//  : 0x02 0x1D 0x13 X0 Y0 Radius 0x03 
// (X0, Y0) -> X, Y ǥ Ʈ , Radius -> 
void Glib_Circle(unsigned int x0, unsigned int y0, unsigned char radius)               
{
    RsOut1(STX);
    RsOut1(0x1D);
    RsOut1(0x13);    
    RsOut1((unsigned char)((x0>>8)&0xFF));
    RsOut1((unsigned char)(x0&0xFF)); 
    RsOut1((unsigned char)((y0>>8)&0xFF));
    RsOut1((unsigned char)(y0&0xFF));
    RsOut1(radius);    
    RsOut1(ETX);                   
}
               
//-------------------- Glib_Ellipse Function ---------------------
//  : 0x02 0x1D 0x14 X0 Y0 a b 0x03 
// (X0, Y0) -> X, Y ǥ Ʈ  
// a -> Horizontal length, b -> Vertical length
void Glib_Ellipse(unsigned int x0, unsigned int y0, unsigned char a, unsigned char b)               
{
    RsOut1(STX);
    RsOut1(0x1D);
    RsOut1(0x14);    
    RsOut1((unsigned char)((x0>>8)&0xFF));
    RsOut1((unsigned char)(x0&0xFF)); 
    RsOut1((unsigned char)((y0>>8)&0xFF));
    RsOut1((unsigned char)(y0&0xFF));                                               
    RsOut1(a);        
    RsOut1(b);    
    RsOut1(ETX);                   
}                                      

//-------------------- Glib_Arc Function ---------------------
//  : 0x02 0x1D 0x15 X0 Y0 Radius StartAngle EndAngle 0x03 
// (X0, Y0) -> X, Y ǥ Ʈ , Radius -> 
// StartAngle -> ۰(2byte , 0~359)
// EndAngle -> (2byte , 0~359)
void Glib_Arc(unsigned int x0, unsigned int y0, unsigned char radius,
              unsigned int sAngle, unsigned int eAngle)               
{
    RsOut1(STX);
    RsOut1(0x1D);
    RsOut1(0x15);    
    RsOut1((unsigned char)((x0>>8)&0xFF));
    RsOut1((unsigned char)(x0&0xFF)); 
    RsOut1((unsigned char)((y0>>8)&0xFF));
    RsOut1((unsigned char)(y0&0xFF));
    RsOut1(radius);                  
    RsOut1((unsigned char)((sAngle>>8)&0xFF));
    RsOut1((unsigned char)(sAngle&0xFF)); 
    RsOut1((unsigned char)((eAngle>>8)&0xFF));
    RsOut1((unsigned char)(eAngle&0xFF));    
    RsOut1(ETX);                   
}
             
//-------------------- Glib_FilledRectangle Function ---------------------
//  : 0x02 0x1D 0x16 X1 Y1 X2 Y2 FillColor 0x03 
// (X1, Y1)~(X2, Y2) -> X, Y ǥ Ʈ    
// FillColor -> R G B   1Ʈ  3Ʈ      
void Glib_FilledRectangle(unsigned int x1, unsigned int y1, unsigned int x2, unsigned int y2,
                          unsigned long fillColor)               
{
    RsOut1(STX);
    RsOut1(0x1D);
    RsOut1(0x16);    
    RsOut1((unsigned char)((x1>>8)&0xFF));
    RsOut1((unsigned char)(x1&0xFF)); 
    RsOut1((unsigned char)((y1>>8)&0xFF));
    RsOut1((unsigned char)(y1&0xFF));
    RsOut1((unsigned char)((x2>>8)&0xFF));
    RsOut1((unsigned char)(x2&0xFF)); 
    RsOut1((unsigned char)((y2>>8)&0xFF));
    RsOut1((unsigned char)(y2&0xFF)); 
    RsOut1((unsigned char)((fillColor>>16)&0xFF));
    RsOut1((unsigned char)((fillColor>>8)&0xFF));
    RsOut1((unsigned char)(fillColor&0xFF));                  
    RsOut1(ETX);                   
}

//-------------------- Glib_FilledCircle Function ---------------------
//  : 0x02 0x1D 0x17 X0 Y0 Radius FillColor 0x03 
// (X0, Y0) -> X, Y ǥ Ʈ , Radius -> 
// FillColor -> R G B   1Ʈ  3Ʈ      
void Glib_FilledCircle(unsigned int x0, unsigned int y0, unsigned char radius, unsigned long fillColor)               
{
    RsOut1(STX);
    RsOut1(0x1D);
    RsOut1(0x17);    
    RsOut1((unsigned char)((x0>>8)&0xFF));
    RsOut1((unsigned char)(x0&0xFF)); 
    RsOut1((unsigned char)((y0>>8)&0xFF));
    RsOut1((unsigned char)(y0&0xFF));
    RsOut1(radius);                         
    RsOut1((unsigned char)((fillColor>>16)&0xFF));
    RsOut1((unsigned char)((fillColor>>8)&0xFF));
    RsOut1((unsigned char)(fillColor&0xFF));    
    RsOut1(ETX);                   
}

//-------------------- Glib_FilledEllipse Function ---------------------
//  : 0x02 0x1D 0x18 X0 Y0 a b FillColor 0x03 
// (X0, Y0) -> X, Y ǥ Ʈ  
// a -> Horizontal length, b -> Vertical length           
// FillColor -> R G B   1Ʈ  3Ʈ      
void Glib_FilledEllipse(unsigned int x0, unsigned int y0, unsigned char a, unsigned char b,
                        unsigned long fillColor)               
{
    RsOut1(STX);
    RsOut1(0x1D);
    RsOut1(0x18);    
    RsOut1((unsigned char)((x0>>8)&0xFF));
    RsOut1((unsigned char)(x0&0xFF)); 
    RsOut1((unsigned char)((y0>>8)&0xFF));
    RsOut1((unsigned char)(y0&0xFF));                                               
    RsOut1(a);        
    RsOut1(b);                                  
    RsOut1((unsigned char)((fillColor>>16)&0xFF));
    RsOut1((unsigned char)((fillColor>>8)&0xFF));
    RsOut1((unsigned char)(fillColor&0xFF));        
    RsOut1(ETX);                   
}

//-------------------- Glib_ClearScreen Function ---------------------
//  : 0x02 0x1D 0x19 FillColor 0x03 
// FillColor -> R G B   1Ʈ  3Ʈ      
void Glib_ClearScreen(unsigned long fillColor)               
{
    RsOut1(STX);
    RsOut1(0x1D);
    RsOut1(0x19);    
    RsOut1((unsigned char)((fillColor>>16)&0xFF));
    RsOut1((unsigned char)((fillColor>>8)&0xFF));
    RsOut1((unsigned char)(fillColor&0xFF));        
    RsOut1(ETX);                   
}

//-------------------- Glib_ClearPartialScreen Function ---------------------
//  : 0x02 0x1D 0x1A X1 Y1 X2 Y2 FillColor 0x03 
// (X1, Y1)~(X2, Y2) -> X, Y ǥ Ʈ    
// FillColor -> R G B   1Ʈ  3Ʈ      
void Glib_ClearPartialScreen(unsigned int x1, unsigned int y1, unsigned int x2, unsigned int y2,
                             unsigned long fillColor)               
{
    RsOut1(STX);
    RsOut1(0x1D);
    RsOut1(0x1A);    
    RsOut1((unsigned char)((x1>>8)&0xFF));
    RsOut1((unsigned char)(x1&0xFF)); 
    RsOut1((unsigned char)((y1>>8)&0xFF));
    RsOut1((unsigned char)(y1&0xFF));
    RsOut1((unsigned char)((x2>>8)&0xFF));
    RsOut1((unsigned char)(x2&0xFF)); 
    RsOut1((unsigned char)((y2>>8)&0xFF));
    RsOut1((unsigned char)(y2&0xFF)); 
    RsOut1((unsigned char)((fillColor>>16)&0xFF));
    RsOut1((unsigned char)((fillColor>>8)&0xFF));
    RsOut1((unsigned char)(fillColor&0xFF));                  
    RsOut1(ETX);                   
}
 
//-------------------- Glib_DisplayImage Function ---------------------
//  : 0x02 0x1D 0x1B ImageIndex X Y 0x03  
// ImageIndex -> Image Index
// X,Y -> X, Y ǥ Ʈ 
void Glib_DisplayImage(unsigned char imageIndex, unsigned int xx, unsigned int yy)               
{
    RsOut1(STX);
    RsOut1(0x1D);
    RsOut1(0x1B);                    
    RsOut1(imageIndex);
    RsOut1((unsigned char)((xx>>8)&0xFF));
    RsOut1((unsigned char)(xx&0xFF)); 
    RsOut1((unsigned char)((yy>>8)&0xFF));
    RsOut1((unsigned char)(yy&0xFF));    
    RsOut1(ETX);                   
}
       
//-------------------- Glib_PushScreen Function ---------------------
//  : 0x02 0x1D 0x1C X1 Y1 X2 Y2 0x03 
// (X1, Y1)~(X2, Y2) -> X, Y ǥ Ʈ    
void Glib_PushScreen(unsigned int x1, unsigned int y1, unsigned int x2, unsigned int y2)               
{
    RsOut1(STX);
    RsOut1(0x1D);
    RsOut1(0x1C);    
    RsOut1((unsigned char)((x1>>8)&0xFF));
    RsOut1((unsigned char)(x1&0xFF)); 
    RsOut1((unsigned char)((y1>>8)&0xFF));
    RsOut1((unsigned char)(y1&0xFF));
    RsOut1((unsigned char)((x2>>8)&0xFF));
    RsOut1((unsigned char)(x2&0xFF)); 
    RsOut1((unsigned char)((y2>>8)&0xFF));
    RsOut1((unsigned char)(y2&0xFF));              
    RsOut1(ETX);                   
}

//-------------------- Glib_PopScreen Function ---------------------
//  : 0x02 0x1D 0x1D X Y 0x03 
// X, Y -> X, Y ǥ Ʈ    
void Glib_PopScreen(unsigned int xx, unsigned int yy)               
{
    RsOut1(STX);
    RsOut1(0x1D);
    RsOut1(0x1D);    
    RsOut1((unsigned char)((xx>>8)&0xFF));
    RsOut1((unsigned char)(xx&0xFF)); 
    RsOut1((unsigned char)((yy>>8)&0xFF));
    RsOut1((unsigned char)(yy&0xFF));
    RsOut1(ETX);                   
}

//-------------------- Glib_OutUserChar Function ---------------------
//  : 0x02 0x1D 0x1E CharIndex 0x03 
// X, Y -> X, Y ǥ Ʈ    
void Glib_OutUserChar(unsigned char charIndex)               
{
    RsOut1(STX);
    RsOut1(0x1D);
    RsOut1(0x1E);    
    RsOut1(charIndex);    
    RsOut1(ETX);                   
}                       


//==================================================================
//                        Ÿ ɱ
//==================================================================                                                                     

//-------------------- Glib_TspBeepOnOff Function ---------------------
//  : 0x02 0x1E 0x14 flag 0x03 
// flag -> 0xA0(use beep), 0x0A(don't use beep, default)
void Glib_TspBeepOnOff(unsigned char flag)
{
    RsOut1(STX);
    RsOut1(0x1E);
    RsOut1(0x14);    
    RsOut1(flag);    
    RsOut1(ETX);    
}
               
//----------------------- Glib_Beep Function ------------------------
//  : 0x02 0x1E 0x14 ms 0x03 
// ms -> milli second 2byte, Ʈ 
void Glib_Beep(unsigned int ms)
{
    RsOut1(STX);
    RsOut1(0x1E);
    RsOut1(0x15);    
    RsOut1((unsigned char)((ms>>8)&0xFF));
    RsOut1((unsigned char)(ms&0xFF)); 
    RsOut1(ETX);    
}

//-------------------- Glib_OutSound Function ---------------------
//  : 0x02 0x1E 0x14 SoundIndex 0x03 
// SoundIndex -> 0~15
void Glib_OutSound(unsigned char soundIndex)
{
    RsOut1(STX);
    RsOut1(0x1E);
    RsOut1(0x16);    
    RsOut1(soundIndex);    
    RsOut1(ETX);    
}














      
